Rdocumentation
powered by
Learn R Programming
sigclust (version 1.0.0)
sigclust-class: Class sigclust
Description
The class sigclust is the output from the function
sigclust
. It is also the input to the plot function
plot-methods
.
Arguments
See Also
sigclust
,
plot-methods
.